/*
 * Video Capture Driver ( Video for Linux 1/2 )
 * for the Matrox Marvel G200 and Rainbow Runner-G series
 *
 * This module is an interface to the G100 and G200 video extension
 * registers.  
 *
 * Copyright (C) 1999  Ryan Drake <stiletto@mediaone.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef MGAVIDEO_H
#define MGAVIDEO_H

#include <linux/i2c.h>

/****************************************************************************
* mga_dev : represents one mga board.  since we can be dealing with multiple
*           boards, all entry points to this module must specify a board
****************************************************************************/
struct mga_dev
{
        struct i2c_bus i2c;

        u8* fb;
        u8* ctrl;

        int inuse;

        /* device info from pci */
        u32 device;
        int irq;                                                                

        /* caps */
        int hasaudio;
        int hastuner;
        int hasdecoder;

        /* private stuff */
        u8* video;
        u8* vbi;
};


/* component device control */
void mgavideo_tuner( struct mga_dev* mga, unsigned int cmd, void* arg );
void mgavideo_audio( struct mga_dev* mga, unsigned int cmd, void* arg );
void mgavideo_decoder( struct mga_dev* mga, unsigned int cmd, void* arg );

#define MGAVIDEO_HAS_TUNER   1
#define MGAVIDEO_HAS_AUDIO   2
#define MGAVIDEO_HAS_DECODER 4
int mgavideo_querycaps( struct mga_dev* mga );

/* video interrupt control */
void mgavideo_ivsync_enable( struct mga_dev* mga, int en );
int mgavideo_ivsync_pending( struct mga_dev* mga );
void mgavideo_ivsync_clear( struct mga_dev* mga );

/* set the next window for the grabber to get */
void mgavideo_grab( struct mga_dev* mga );

/* find next mga adapter */
struct mga_dev* mgavideo_get( void );

/* release a mga adapter that is not needed anymore */
void mgavideo_release( struct mga_dev* mga );

#endif /* MGAVIDEO_H */
